@@ -24,16 +24,3 @@ pub fn type_authentication_code(api: &Api) {
     .expect("failed to check authentication code");
   debug!("Set authentication code: {}", code);
 }
-
-#[allow(dead_code)]
-pub fn type_and_register(api: &Api) {
-  let first_name = thelp::typed_with_message("Please input first name:");
-  let last_name = thelp::typed_with_message("Please input last name:");
-  debug!("You name is {} {}", first_name, last_name);
-  api.event_api()
-    .register_user(RegisterUser::builder()
-    .first_name(first_name)
-    .last_name(last_name)
-    .build())
-    .expect("failed to register user");
-}
