@@ -26,12 +26,6 @@ impl Observer {
 
       TdType::TestUseUpdate(value) => value.extra(),
 
-      TdType::UpdateActiveNotifications(value) => value.extra(),
-
-      TdType::UpdateAnimatedEmojiMessageClicked(value) => value.extra(),
-
-      TdType::UpdateAnimationSearchParameters(value) => value.extra(),
-
       TdType::UpdateAuthorizationState(value) => value.extra(),
 
       TdType::UpdateBasicGroup(value) => value.extra(),
@@ -40,66 +34,38 @@ impl Observer {
 
       TdType::UpdateCall(value) => value.extra(),
 
-      TdType::UpdateChatAction(value) => value.extra(),
-
-      TdType::UpdateChatActionBar(value) => value.extra(),
-
       TdType::UpdateChatDefaultDisableNotification(value) => value.extra(),
 
       TdType::UpdateChatDraftMessage(value) => value.extra(),
 
-      TdType::UpdateChatFilters(value) => value.extra(),
-
-      TdType::UpdateChatHasProtectedContent(value) => value.extra(),
-
-      TdType::UpdateChatHasScheduledMessages(value) => value.extra(),
-
-      TdType::UpdateChatIsBlocked(value) => value.extra(),
-
       TdType::UpdateChatIsMarkedAsUnread(value) => value.extra(),
 
+      TdType::UpdateChatIsPinned(value) => value.extra(),
+
+      TdType::UpdateChatIsSponsored(value) => value.extra(),
+
       TdType::UpdateChatLastMessage(value) => value.extra(),
 
-      TdType::UpdateChatMember(value) => value.extra(),
-
-      TdType::UpdateChatMessageSender(value) => value.extra(),
-
-      TdType::UpdateChatMessageTtl(value) => value.extra(),
-
       TdType::UpdateChatNotificationSettings(value) => value.extra(),
 
-      TdType::UpdateChatOnlineMemberCount(value) => value.extra(),
-
-      TdType::UpdateChatPendingJoinRequests(value) => value.extra(),
-
-      TdType::UpdateChatPermissions(value) => value.extra(),
+      TdType::UpdateChatOrder(value) => value.extra(),
 
       TdType::UpdateChatPhoto(value) => value.extra(),
 
-      TdType::UpdateChatPosition(value) => value.extra(),
-
       TdType::UpdateChatReadInbox(value) => value.extra(),
 
       TdType::UpdateChatReadOutbox(value) => value.extra(),
 
       TdType::UpdateChatReplyMarkup(value) => value.extra(),
 
-      TdType::UpdateChatTheme(value) => value.extra(),
-
-      TdType::UpdateChatThemes(value) => value.extra(),
-
       TdType::UpdateChatTitle(value) => value.extra(),
 
       TdType::UpdateChatUnreadMentionCount(value) => value.extra(),
 
-      TdType::UpdateChatVideoChat(value) => value.extra(),
-
       TdType::UpdateConnectionState(value) => value.extra(),
 
       TdType::UpdateDeleteMessages(value) => value.extra(),
 
-      TdType::UpdateDiceEmojis(value) => value.extra(),
-
       TdType::UpdateFavoriteStickers(value) => value.extra(),
 
       TdType::UpdateFile(value) => value.extra(),
@@ -108,12 +74,6 @@ impl Observer {
 
       TdType::UpdateFileGenerationStop(value) => value.extra(),
 
-      TdType::UpdateGroupCall(value) => value.extra(),
-
-      TdType::UpdateGroupCallParticipant(value) => value.extra(),
-
-      TdType::UpdateHavePendingNotifications(value) => value.extra(),
-
       TdType::UpdateInstalledStickerSets(value) => value.extra(),
 
       TdType::UpdateLanguagePackStrings(value) => value.extra(),
@@ -124,12 +84,6 @@ impl Observer {
 
       TdType::UpdateMessageEdited(value) => value.extra(),
 
-      TdType::UpdateMessageInteractionInfo(value) => value.extra(),
-
-      TdType::UpdateMessageIsPinned(value) => value.extra(),
-
-      TdType::UpdateMessageLiveLocationViewed(value) => value.extra(),
-
       TdType::UpdateMessageMentionRead(value) => value.extra(),
 
       TdType::UpdateMessageSendAcknowledged(value) => value.extra(),
@@ -138,14 +92,12 @@ impl Observer {
 
       TdType::UpdateMessageSendSucceeded(value) => value.extra(),
 
-      TdType::UpdateNewCallSignalingData(value) => value.extra(),
+      TdType::UpdateMessageViews(value) => value.extra(),
 
       TdType::UpdateNewCallbackQuery(value) => value.extra(),
 
       TdType::UpdateNewChat(value) => value.extra(),
 
-      TdType::UpdateNewChatJoinRequest(value) => value.extra(),
-
       TdType::UpdateNewChosenInlineResult(value) => value.extra(),
 
       TdType::UpdateNewCustomEvent(value) => value.extra(),
@@ -162,16 +114,8 @@ impl Observer {
 
       TdType::UpdateNewShippingQuery(value) => value.extra(),
 
-      TdType::UpdateNotification(value) => value.extra(),
-
-      TdType::UpdateNotificationGroup(value) => value.extra(),
-
       TdType::UpdateOption(value) => value.extra(),
 
-      TdType::UpdatePoll(value) => value.extra(),
-
-      TdType::UpdatePollAnswer(value) => value.extra(),
-
       TdType::UpdateRecentStickers(value) => value.extra(),
 
       TdType::UpdateSavedAnimations(value) => value.extra(),
@@ -180,14 +124,8 @@ impl Observer {
 
       TdType::UpdateSecretChat(value) => value.extra(),
 
-      TdType::UpdateSelectedBackground(value) => value.extra(),
-
       TdType::UpdateServiceNotification(value) => value.extra(),
 
-      TdType::UpdateStickerSet(value) => value.extra(),
-
-      TdType::UpdateSuggestedActions(value) => value.extra(),
-
       TdType::UpdateSupergroup(value) => value.extra(),
 
       TdType::UpdateSupergroupFullInfo(value) => value.extra(),
@@ -202,173 +140,89 @@ impl Observer {
 
       TdType::UpdateUser(value) => value.extra(),
 
+      TdType::UpdateUserChatAction(value) => value.extra(),
+
       TdType::UpdateUserFullInfo(value) => value.extra(),
 
       TdType::UpdateUserPrivacySettingRules(value) => value.extra(),
 
       TdType::UpdateUserStatus(value) => value.extra(),
 
-      TdType::UpdateUsersNearby(value) => value.extra(),
-
 
       TdType::AuthorizationState(value) => value.extra(),
 
-      TdType::CanTransferOwnershipResult(value) => value.extra(),
-
-      TdType::ChatStatistics(value) => value.extra(),
-
       TdType::CheckChatUsernameResult(value) => value.extra(),
 
-      TdType::CheckStickerSetNameResult(value) => value.extra(),
-
-      TdType::InternalLinkType(value) => value.extra(),
-
-      TdType::JsonValue(value) => value.extra(),
-
       TdType::LanguagePackStringValue(value) => value.extra(),
 
-      TdType::LogStream(value) => value.extra(),
-
-      TdType::LoginUrlInfo(value) => value.extra(),
-
-      TdType::MessageFileType(value) => value.extra(),
-
       TdType::OptionValue(value) => value.extra(),
 
       TdType::PassportElement(value) => value.extra(),
 
-      TdType::ResetPasswordResult(value) => value.extra(),
-
-      TdType::StatisticalGraph(value) => value.extra(),
-
       TdType::Update(value) => value.extra(),
 
       TdType::AccountTtl(value) => value.extra(),
 
-      TdType::AnimatedEmoji(value) => value.extra(),
-
       TdType::Animations(value) => value.extra(),
 
       TdType::AuthenticationCodeInfo(value) => value.extra(),
 
-      TdType::AutoDownloadSettingsPresets(value) => value.extra(),
-
-      TdType::Background(value) => value.extra(),
-
-      TdType::Backgrounds(value) => value.extra(),
-
-      TdType::BankCardInfo(value) => value.extra(),
-
       TdType::BasicGroup(value) => value.extra(),
 
       TdType::BasicGroupFullInfo(value) => value.extra(),
 
-      TdType::BotCommands(value) => value.extra(),
-
       TdType::CallId(value) => value.extra(),
 
       TdType::CallbackQueryAnswer(value) => value.extra(),
 
       TdType::Chat(value) => value.extra(),
 
-      TdType::ChatAdministrators(value) => value.extra(),
-
       TdType::ChatEvents(value) => value.extra(),
 
-      TdType::ChatFilter(value) => value.extra(),
-
-      TdType::ChatFilterInfo(value) => value.extra(),
-
       TdType::ChatInviteLink(value) => value.extra(),
 
-      TdType::ChatInviteLinkCounts(value) => value.extra(),
-
       TdType::ChatInviteLinkInfo(value) => value.extra(),
 
-      TdType::ChatInviteLinkMembers(value) => value.extra(),
-
-      TdType::ChatInviteLinks(value) => value.extra(),
-
-      TdType::ChatJoinRequests(value) => value.extra(),
-
-      TdType::ChatLists(value) => value.extra(),
-
       TdType::ChatMember(value) => value.extra(),
 
       TdType::ChatMembers(value) => value.extra(),
 
-      TdType::ChatPhotos(value) => value.extra(),
+      TdType::ChatReportSpamState(value) => value.extra(),
 
       TdType::Chats(value) => value.extra(),
 
-      TdType::ChatsNearby(value) => value.extra(),
-
       TdType::ConnectedWebsites(value) => value.extra(),
 
       TdType::Count(value) => value.extra(),
 
-      TdType::Countries(value) => value.extra(),
-
       TdType::CustomRequestResult(value) => value.extra(),
 
-      TdType::DatabaseStatistics(value) => value.extra(),
-
       TdType::DeepLinkInfo(value) => value.extra(),
 
       TdType::EmailAddressAuthenticationCodeInfo(value) => value.extra(),
 
-      TdType::Emojis(value) => value.extra(),
-
       TdType::Error(value) => value.extra(),
 
       TdType::File(value) => value.extra(),
 
-      TdType::FilePart(value) => value.extra(),
-
       TdType::FormattedText(value) => value.extra(),
 
       TdType::FoundMessages(value) => value.extra(),
 
       TdType::GameHighScores(value) => value.extra(),
 
-      TdType::GroupCall(value) => value.extra(),
-
-      TdType::GroupCallId(value) => value.extra(),
-
       TdType::Hashtags(value) => value.extra(),
 
-      TdType::HttpUrl(value) => value.extra(),
-
       TdType::ImportedContacts(value) => value.extra(),
 
       TdType::InlineQueryResults(value) => value.extra(),
 
-      TdType::LanguagePackInfo(value) => value.extra(),
-
       TdType::LanguagePackStrings(value) => value.extra(),
 
       TdType::LocalizationTargetInfo(value) => value.extra(),
 
-      TdType::LogTags(value) => value.extra(),
-
-      TdType::LogVerbosityLevel(value) => value.extra(),
-
       TdType::Message(value) => value.extra(),
 
-      TdType::MessageCalendar(value) => value.extra(),
-
-      TdType::MessageLink(value) => value.extra(),
-
-      TdType::MessageLinkInfo(value) => value.extra(),
-
-      TdType::MessagePositions(value) => value.extra(),
-
-      TdType::MessageSenders(value) => value.extra(),
-
-      TdType::MessageStatistics(value) => value.extra(),
-
-      TdType::MessageThreadInfo(value) => value.extra(),
-
       TdType::Messages(value) => value.extra(),
 
       TdType::NetworkStatistics(value) => value.extra(),
@@ -381,8 +235,6 @@ impl Observer {
 
       TdType::PassportElements(value) => value.extra(),
 
-      TdType::PassportElementsWithErrors(value) => value.extra(),
-
       TdType::PasswordState(value) => value.extra(),
 
       TdType::PaymentForm(value) => value.extra(),
@@ -391,15 +243,11 @@ impl Observer {
 
       TdType::PaymentResult(value) => value.extra(),
 
-      TdType::PhoneNumberInfo(value) => value.extra(),
-
       TdType::Proxies(value) => value.extra(),
 
       TdType::Proxy(value) => value.extra(),
 
-      TdType::PushReceiverId(value) => value.extra(),
-
-      TdType::RecommendedChatFilters(value) => value.extra(),
+      TdType::PublicMessageLink(value) => value.extra(),
 
       TdType::RecoveryEmailAddress(value) => value.extra(),
 
@@ -409,13 +257,9 @@ impl Observer {
 
       TdType::SecretChat(value) => value.extra(),
 
-      TdType::Session(value) => value.extra(),
-
       TdType::Sessions(value) => value.extra(),
 
-      TdType::SponsoredMessage(value) => value.extra(),
-
-      TdType::Sticker(value) => value.extra(),
+      TdType::StickerEmojis(value) => value.extra(),
 
       TdType::StickerSet(value) => value.extra(),
 
@@ -453,18 +297,20 @@ impl Observer {
 
       TdType::TextEntities(value) => value.extra(),
 
-      TdType::Updates(value) => value.extra(),
-
       TdType::User(value) => value.extra(),
 
       TdType::UserFullInfo(value) => value.extra(),
 
       TdType::UserPrivacySettingRules(value) => value.extra(),
 
+      TdType::UserProfilePhotos(value) => value.extra(),
+
       TdType::Users(value) => value.extra(),
 
       TdType::ValidatedOrderInfo(value) => value.extra(),
 
+      TdType::Wallpapers(value) => value.extra(),
+
       TdType::WebPage(value) => value.extra(),
 
       TdType::WebPageInstantView(value) => value.extra(),
